#include <CapacitiveSensor.h>

void activateSMA();
void deactivateSMA();

// Pin configuration for the capacitive sensor
const int sensorPin = 4;    // Connect sensor's signal pin to Arduino pin 4
const int receivePin = 5;
const int threshold = 100;  // Threshold value to differentiate a "touch" or "not touch"
const int mosfetPin = 9;       // Pin to control MOSFET or transistor
int bluePin = 6;

// Create a CapacitiveSensor object
CapacitiveSensor sensor = CapacitiveSensor(sensorPin, receivePin);  // Sensor pin connected to pin 4, using pin 5 as ground reference

void setup() {
  Serial.begin(9600);   // Start serial communication
  Serial.println("Capacitive Sensor Test");
  pinMode(mosfetPin, OUTPUT); // Set control pin as an output
   // Ensure the MOSFET is off at startup (in case there was any prior state)
  digitalWrite(mosfetPin, LOW);
  pinMode(bluePin, OUTPUT);
}

void loop() {
  long sensorValue = sensor.capacitiveSensor(30);  // Read sensor value with 30 sample readings

  Serial.print("Sensor Value: ");
  Serial.println(sensorValue);

  // If sensor value exceeds threshold, it is considered "touched"
  if (sensorValue > threshold) {
    Serial.println("Touched - Activating SMA Wire");
    activateSMA();
  } else {
    Serial.println("Not Touched - Deactivating SMA Wire");
    deactivateSMA();
  }
  delay(1000);  // Small delay to avoid overwhelming the serial output
}
// Function to activate SMA wire (turn on MOSFET or transistor)
void activateSMA() {
// Gradually heat the Flexinol wire
  analogWrite(mosfetPin, 255);  // Control the MOSFET with PWM
  // Turn blue LED on
  digitalWrite(bluePin, HIGH);
}

// Function to deactivate SMA wire (turn off MOSFET or transistor)
void deactivateSMA() {
  // Send a LOW signal to control pin, turning off the MOSFET or transistor
  analogWrite(mosfetPin, 0);
  // Turn blue LED off
  digitalWrite(bluePin, LOW);
}

